@@ -1168,7 +1168,7 @@ def randsphere(n, rstate=None):
     """Draw a point uniformly within an `n`-dimensional unit sphere."""
 
     z = rstate.standard_normal(size=n)  # initial n-dim vector
-    xhat = z * (rstate.uniform()**(1. / n) / lalg.norm(z))  # scale
+    xhat = z * (rstate.uniform()**(1. / n) / lalg.norm(z, check_finite=False))  # scale
     return xhat
 
 
